summaryrefslogtreecommitdiff
path: root/misc/dashboard
diff options
context:
space:
mode:
authorDavid Symonds <dsymonds@golang.org>2013-07-29 12:08:19 +1000
committerDavid Symonds <dsymonds@golang.org>2013-07-29 12:08:19 +1000
commit5ba52b7cc2498ab9b1fd745cd96920772088d41b (patch)
treed512fd8cd4282b68c02ee747f1e7204a328b69b7 /misc/dashboard
parent9d01c9bf9fca3152694a80a00ea117b6f496e010 (diff)
downloadgo-5ba52b7cc2498ab9b1fd745cd96920772088d41b.tar.gz
misc/dashboard: don't update tip tag for release branch commits.
This will mean that sub-repositories won't get built against the release branch. They are often not compatible because the subrepos often run ahead of the current release (e.g. go.tools is using new additions to go/ast, and go.net is using new things in syscall) so there's little point in checking them against cherrypick commits when they'll be tested against those commits on tip anyway. R=golang-dev, adg CC=golang-dev https://codereview.appspot.com/12001043
Diffstat (limited to 'misc/dashboard')
-rw-r--r--misc/dashboard/app/build/handler.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/misc/dashboard/app/build/handler.go b/misc/dashboard/app/build/handler.go
index 1a1118641..4ba05e3a6 100644
--- a/misc/dashboard/app/build/handler.go
+++ b/misc/dashboard/app/build/handler.go
@@ -11,6 +11,7 @@ import (
"errors"
"fmt"
"net/http"
+ "strings"
"appengine"
"appengine/datastore"
@@ -98,8 +99,8 @@ func addCommit(c appengine.Context, com *Commit) error {
return errors.New("parent commit not found")
}
}
- // update the tip Tag if this is the Go repo
- if p.Path == "" {
+ // update the tip Tag if this is the Go repo and this isn't on a release branch
+ if p.Path == "" && !strings.HasPrefix(com.Desc, "[release-branch") {
t := &Tag{Kind: "tip", Hash: com.Hash}
if _, err = datastore.Put(c, t.Key(c), t); err != nil {
return fmt.Errorf("putting Tag: %v", err)